summaryrefslogtreecommitdiffstats
path: root/libhb/stream.c
diff options
context:
space:
mode:
authorBradley Sepos <[email protected]>2018-05-28 23:58:51 -0400
committerBradley Sepos <[email protected]>2018-05-28 23:58:51 -0400
commitd1222dd59cac26a591ce3b93bdf3adc5e1733568 (patch)
tree7fb115349d9042e3c782860ad50fdc545095e829 /libhb/stream.c
parent5a52b9265c71296f676be899f7f8ef893e12f7bb (diff)
contrib: Use AV_CODEC_ID_ASS for FFmpeg.
Diffstat (limited to 'libhb/stream.c')
-rw-r--r--libhb/stream.c4
1 files changed, 2 insertions, 2 deletions
diff --git a/libhb/stream.c b/libhb/stream.c
index 3ecc04356..ba9a17835 100644
--- a/libhb/stream.c
+++ b/libhb/stream.c
@@ -5327,7 +5327,7 @@ static void add_ffmpeg_subtitle( hb_title_t *title, hb_stream_t *stream, int id
subtitle->config.dest = PASSTHRUSUB;
subtitle->codec = WORK_DECTX3GSUB;
break;
- case AV_CODEC_ID_SSA:
+ case AV_CODEC_ID_ASS:
subtitle->format = TEXTSUB;
subtitle->source = SSASUB;
subtitle->config.dest = PASSTHRUSUB;
@@ -5852,7 +5852,7 @@ hb_buffer_t * hb_ffmpeg_read( hb_stream_t *stream )
* either field. This is not a problem because the VOB decoder can extract this
* information from the packet payload itself.
*
* SSA subtitles (AV_CODEC_ID_SSA) do not have their duration stored in
* either field. This is not a problem because the SSA decoder can extract this
* information from the packet payload itself.
*/
@@ -5852,7 +5852,7 @@ hb_buffer_t * hb_ffmpeg_read( hb_stream_t *stream )
* information from the packet payload itself.
*
- * SSA subtitles (AV_CODEC_ID_SSA) do not have their duration stored in
+ * SSA subtitles (AV_CODEC_ID_ASS) do not have their duration stored in
* either field. This is not a problem because the SSA decoder can extract this
* information from the packet payload itself.